Index — sagace 2025 documentation

# Index

_ | A | B | D | E | F | G | H | I | L | M | P | R | S | T

## _

_abc_impl (sagace.auth.domain.authentication_repository.AuthenticationRepository attribute) (sagace.auth.infrastructure.authentication_api.AuthenticationAPI attribute) (sagace.core.api_client.APIClient attribute) (sagace.core.http_api_client.HTTPAPIClient attribute) (sagace.core.storage.file_storage.FileTokenStorage attribute) (sagace.core.storage.memory_storage.MemoryTokenStorage attribute) (sagace.core.storage.redis_storage.RedisTokenStorage attribute) (sagace.core.token_storage.TokenStorage attribute) | _get_headers() (sagace.core.http_api_client.HTTPAPIClient method)

## A

access_token (sagace.core.token.Token attribute) APIClient (class in sagace.core.api_client) APIRequestError application_name (sagace.core.token.Token attribute) ApplicationError AUTH_URL (sagace.auth.infrastructure.authentication_api.AuthenticationAPI attribute) | authenticate() (sagace.auth.domain.authentication_repository.AuthenticationRepository method) (sagace.auth.infrastructure.authentication_api.AuthenticationAPI method) AuthenticateUser (class in sagace.auth.application.authentication_use_case) AuthenticationAPI (class in sagace.auth.infrastructure.authentication_api) AuthenticationFailedError AuthenticationRepository (class in sagace.auth.domain.authentication_repository) AuthenticationService (class in sagace.auth.interfaces.authentication_service)

## B

BASE_URL (sagace.auth.infrastructure.authentication_api.AuthenticationAPI attribute) | base_url (sagace.core.token.Token attribute)

## D

delete() (sagace.core.http_api_client.HTTPAPIClient method) | description (sagace.core.token.Token attribute) DomainError

## E

execute() (sagace.auth.application.authentication_use_case.AuthenticateUser method)

## F

FileTokenStorage (class in sagace.core.storage.file_storage)

## G

get() (sagace.core.http_api_client.HTTPAPIClient method) get_auth_header() (sagace.core.token.Token method) get_token() (sagace.core.storage.file_storage.FileTokenStorage method) (sagace.core.storage.memory_storage.MemoryTokenStorage method) (sagace.core.storage.redis_storage.RedisTokenStorage method) (sagace.core.token_storage.TokenStorage method)

## H

HTTPAPIClient (class in sagace.core.http_api_client)

## I

InfrastructureError | InterfaceError

## L

login() (sagace.auth.interfaces.authentication_service.AuthenticationService method)

## M

MemoryTokenStorage (class in sagace.core.storage.memory_storage) module sagace sagace.auth sagace.auth.application sagace.auth.application.authentication_use_case sagace.auth.domain sagace.auth.domain.authentication_repository sagace.auth.infrastructure sagace.auth.infrastructure.authentication_api sagace.auth.interfaces sagace.auth.interfaces.authentication_service sagace.core sagace.core.api_client sagace.core.http_api_client sagace.core.storage sagace.core.storage.file_storage sagace.core.storage.memory_storage sagace.core.storage.redis_storage sagace.core.token sagace.core.token_storage sagace.exceptions sagace.exceptions.application sagace.exceptions.application.application_error sagace.exceptions.domain sagace.exceptions.domain.api_request_error sagace.exceptions.domain.domain_error sagace.exceptions.domain.permission_denied_error sagace.exceptions.domain.token_expired_error sagace.exceptions.infrastructure sagace.exceptions.infrastructure.authentication_error sagace.exceptions.infrastructure.infrastructure_error sagace.exceptions.interfaces sagace.exceptions.interfaces.interface_error sagace.samples sagace.samples.basic_autentication

## P

PermissionDeniedError | post() (sagace.core.http_api_client.HTTPAPIClient method) put() (sagace.core.http_api_client.HTTPAPIClient method)

## R

RedisTokenStorage (class in sagace.core.storage.redis_storage) | request() (sagace.core.api_client.APIClient method) (sagace.core.http_api_client.HTTPAPIClient method)

## S

sagace module sagace.auth module sagace.auth.application module sagace.auth.application.authentication_use_case module sagace.auth.domain module sagace.auth.domain.authentication_repository module sagace.auth.infrastructure module sagace.auth.infrastructure.authentication_api module sagace.auth.interfaces module sagace.auth.interfaces.authentication_service module sagace.core module sagace.core.api_client module sagace.core.http_api_client module sagace.core.storage module sagace.core.storage.file_storage module sagace.core.storage.memory_storage module sagace.core.storage.redis_storage module sagace.core.token module | sagace.core.token_storage module sagace.exceptions module sagace.exceptions.application module sagace.exceptions.application.application_error module sagace.exceptions.domain module sagace.exceptions.domain.api_request_error module sagace.exceptions.domain.domain_error module sagace.exceptions.domain.permission_denied_error module sagace.exceptions.domain.token_expired_error module sagace.exceptions.infrastructure module sagace.exceptions.infrastructure.authentication_error module sagace.exceptions.infrastructure.infrastructure_error module sagace.exceptions.interfaces module sagace.exceptions.interfaces.interface_error module sagace.samples module sagace.samples.basic_autentication module save_token() (sagace.core.storage.file_storage.FileTokenStorage method) (sagace.core.storage.memory_storage.MemoryTokenStorage method) (sagace.core.storage.redis_storage.RedisTokenStorage method) (sagace.core.token_storage.TokenStorage method)

## T

Token (class in sagace.core.token) token_type (sagace.core.token.Token attribute) | TokenExpiredError TokenStorage (class in sagace.core.token_storage)